<?php
if(!class_exists("Gc_Message_Box_Admin_Controller")){
	class Gc_Message_Box_Admin_Controller implements Gc_Controller_Interface {
        protected $namespace;
        protected $options;
		protected $this_plugin = 'gc-message-box/main.php';

        public function __construct($namespace){
            $this->namespace = $namespace;

        }
        public function initialize(){
            $this->options = Gc_Option_Repository_Factory::get_instance()->get_namespace($this->namespace);
        }
        public function initialize_hooks(){
		    add_action( 'init', array($this, 'scripts_init') );
		    add_action( 'admin_init', array($this, 'admin_init') );
		    add_action( 'admin_menu', array($this, 'add_sub_menu') );
			add_action( 'wp_ajax_nopriv_gc-message-box', array($this,'info'));  
			add_filter( 'plugin_action_links', array($this, 'add_action_link'), 10, 2 );
		}

        public function info(){
            die('{"ver":"'.get_message_box_version().'"}');  
		}

        public function admin_init() {
            add_settings_section( 'style_settings', 'Style Settings', array($this, 'style_sub_message'), 'style_options');
            add_settings_section( 'general_settings', 'General Settings', array($this, 'general_sub_message'), 'general_options');
        }

        public function add_sub_menu() {
            add_submenu_page( 'plugins.php', 'GC Message Box Options', 'GC Message Box','manage_options', 'gc_message_box', array($this, 'sub_menu_page'));
        }

        public function sub_menu_page() {
            $this->init_values();
            if ( !current_user_can( 'manage_options' ) )  {
                wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
            }
            $renderer = new Gc_Message_Box_Admin_Renderer($this->namespace,$this,$this->options);
			$renderer->render("");
        }
		
		public function plugin_options_url() {
            return admin_url( 'plugins.php?page=gc_message_box' );
        }


        public function add_action_link($links, $file) {
            if ( $file == $this->this_plugin ) {
                $settings_link = '<a href="' . $this->plugin_options_url() . '">' . __( 'Settings' ) . '</a>';
                array_unshift( $links, $settings_link );
            }
            return $links;
        }

        public function init_values() {
            $installedOption = $this->options->get("installed");
            if ($installedOption->get_value() == "true") {
                return;
            }
            $options = $this->get_options();
            foreach ($options as $key => $opt) {
                $opt->save();
            }
            $installedOption->set_value("true");
            $installedOption->save();
        }

        public function get_options(){
            return $this->options->get_options();

        }    



        public function style_sub_message() {
            __( 'Options for styling the GC Message Box' );
        }
        
        public function general_sub_message() {
            __( 'General options for the GC Message Box' );
        }


		public function scripts_init(){
            wp_enqueue_style( 'farbtastic' );
            wp_register_style( 'gc_message_box_admin_style', plugins_url('gc-message-box/style-gc-message-box-admin.css') );
            wp_enqueue_style( 'gc_message_box_admin_style' );
            wp_enqueue_script( 'jquery' );
            wp_enqueue_script( 'farbtastic' );

		}

		public function handle_request(){
            if (!isset($_REQUEST['Submit_gc_message_box']) or !isset($_REQUEST['post'])) {
                return;
            }

            $options = $this->get_options();
			
            foreach($options as $option) {
                if (isset($_REQUEST['post'][$option->get_name()])) {
                    $option->set_value($_REQUEST['post'][$option->get_name()]);
                } elseif($option->is_checkbox()) {
                    $option->set_checked(false);
                }else{
                    continue;
                }
                $option->save();
            }
		}
	}
}